@@ -16,7 +16,8 @@ from .exceptions import (DgtoolsErrorSymbolUndefined, DgtoolsErrorSymbolAlreadyD
                          DgtoolsErrorStackOverflow, DgtoolsError)
 from .output_render_html import Output_Render_HTML
 from .callbacks import (DigiruleCallbackComOutStdout, DigiruleCallbackComOutStoreMem, 
-                        DigiruleCallbackComInUserInteraction, DigiruleCallbackInputUserInteraction)
+                        DigiruleCallbackComInUserInteraction, DigiruleCallbackInputUserInteraction,
+                        DigiruleCallbackPinInUserInteraction)
 from .lexer import DigiruleASMLexer
 from .makefile_rw import DgToolsMakefileParser
                                 
